@@ -1,6 +1,6 @@
 <?php
 /*
- * $Horde: horde/login.php,v 2.55.2.19 2003/01/18 22:57:20 slusarz Exp $
+ * $Horde: horde/login.php,v 2.55.2.21 2003/05/27 17:14:31 slusarz Exp $
  *
  * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2003 Jon Parise <jon@horde.org>
@@ -30,6 +30,10 @@ if (Horde::getFormData('reason') == 'logout') {
 
 if (isset($_POST['horde_user']) &&
     isset($_POST['horde_pass'])) {
+    /* Destroy any existing session on login and make sure to use a
+       new session ID, to avoid session fixation issues. */
+    Horde::getCleanSession();
+
     $auth = &Auth::singleton($conf['auth']['driver'], $conf['auth']['params']);
     if ($auth->authenticate(Horde::getFormData('horde_user'),
                             array('password' => Horde::getFormData('horde_pass')))) {
@@ -101,5 +105,3 @@ if (Auth::getAuth()) {
 require HORDE_TEMPLATES . '/common-header.inc';
 require HORDE_TEMPLATES . '/login/' . $template;
 require HORDE_TEMPLATES . '/common-footer.inc';
-
-?>
